@@ -1,7 +1,10 @@
 use {
   super::*,
   clap::{
-    builder::{styling::AnsiColor, FalseyValueParser, Styles},
+    builder::{
+      styling::{AnsiColor, Effects},
+      FalseyValueParser, Styles,
+    },
     parser::ValuesRef,
     value_parser, Arg, ArgAction, ArgGroup, ArgMatches, Command,
   },
@@ -9,6 +12,8 @@ use {
 
 #[derive(Debug, PartialEq)]
 pub(crate) struct Config {
+  pub(crate) alias_style: AliasStyle,
+  pub(crate) allow_missing: bool,
   pub(crate) check: bool,
   pub(crate) color: Color,
   pub(crate) command_color: Option<ansi_term::Color>,
@@ -52,6 +57,7 @@ mod cmd {
   pub(crate) const INIT: &str = "INIT";
   pub(crate) const LIST: &str = "LIST";
   pub(crate) const MAN: &str = "MAN";
+  pub(crate) const REQUEST: &str = "REQUEST";
   pub(crate) const SHOW: &str = "SHOW";
   pub(crate) const SUMMARY: &str = "SUMMARY";
   pub(crate) const VARIABLES: &str = "VARIABLES";
@@ -68,6 +74,7 @@ mod cmd {
     INIT,
     LIST,
     MAN,
+    REQUEST,
     SHOW,
     SUMMARY,
     VARIABLES,
@@ -80,6 +87,8 @@ mod cmd {
 }
 
 mod arg {
+  pub(crate) const ALIAS_STYLE: &str = "ALIAS_STYLE";
+  pub(crate) const ALLOW_MISSING: &str = "ALLOW-MISSING";
   pub(crate) const ARGUMENTS: &str = "ARGUMENTS";
   pub(crate) const CHECK: &str = "CHECK";
   pub(crate) const CHOOSER: &str = "CHOOSER";
@@ -130,10 +139,23 @@ impl Config {
       .trailing_var_arg(true)
       .styles(
         Styles::styled()
-          .header(AnsiColor::Yellow.on_default())
+          .error(AnsiColor::Red.on_default() | Effects::BOLD)
+          .header(AnsiColor::Yellow.on_default() | Effects::BOLD)
+          .invalid(AnsiColor::Red.on_default())
           .literal(AnsiColor::Green.on_default())
-          .placeholder(AnsiColor::Green.on_default())
-          .usage(AnsiColor::Yellow.on_default()),
+          .placeholder(AnsiColor::Cyan.on_default())
+          .usage(AnsiColor::Yellow.on_default() | Effects::BOLD)
+          .valid(AnsiColor::Green.on_default()),
+      )
+      .arg(
+        Arg::new(arg::ALIAS_STYLE)
+          .long("alias-style")
+          .env("JUST_ALIAS_STYLE")
+          .action(ArgAction::Set)
+          .value_parser(clap::value_parser!(AliasStyle))
+          .default_value("right")
+          .help("Set list command alias display style")
+          .conflicts_with(arg::NO_ALIASES),
       )
       .arg(
         Arg::new(arg::CHECK)
@@ -267,7 +289,7 @@ impl Config {
           .env("JUST_LIST_SUBMODULES")
           .help("List recipes in submodules")
           .action(ArgAction::SetTrue)
-          .env("JUST_LIST_SUBMODULES"),
+          .requires(cmd::LIST),
       )
       .arg(
         Arg::new(arg::NO_ALIASES)
@@ -315,6 +337,13 @@ impl Config {
           .help("Suppress all output")
           .conflicts_with(arg::DRY_RUN),
       )
+      .arg(
+        Arg::new(arg::ALLOW_MISSING)
+          .long("allow-missing")
+          .env("JUST_ALLOW_MISSING")
+          .action(ArgAction::SetTrue)
+          .help("Ignore missing recipe and module errors"),
+      )
       .arg(
         Arg::new(arg::SET)
           .long("set")
@@ -495,10 +524,10 @@ impl Config {
           .short('l')
           .long("list")
           .num_args(0..)
-          .value_name("PATH")
+          .value_name("MODULE")
           .action(ArgAction::Set)
           .conflicts_with(arg::ARGUMENTS)
-          .help("List available recipes")
+          .help("List available recipes in <MODULE> or root if omitted")
           .help_heading(cmd::HEADING),
       )
       .arg(
@@ -508,6 +537,17 @@ impl Config {
           .help("Print man page")
           .help_heading(cmd::HEADING),
       )
+      .arg(
+        Arg::new(cmd::REQUEST)
+          .long("request")
+          .action(ArgAction::Set)
+          .hide(true)
+          .help(
+            "Execute <REQUEST>. For internal testing purposes only. May be changed or removed at \
+            any time.",
+          )
+          .help_heading(cmd::REQUEST),
+      )
       .arg(
         Arg::new(cmd::SHOW)
           .short('s')
@@ -687,6 +727,11 @@ impl Config {
       }
     } else if matches.get_flag(cmd::MAN) {
       Subcommand::Man
+    } else if let Some(request) = matches.get_one::<String>(cmd::REQUEST) {
+      Subcommand::Request {
+        request: serde_json::from_str(request)
+          .map_err(|source| ConfigError::RequestParse { source })?,
+      }
     } else if let Some(path) = matches.get_many::<String>(cmd::SHOW) {
       Subcommand::Show {
         path: Self::parse_module_path(path)?,
@@ -706,6 +751,11 @@ impl Config {
     let explain = matches.get_flag(arg::EXPLAIN);
 
     Ok(Self {
+      alias_style: matches
+        .get_one::<AliasStyle>(arg::ALIAS_STYLE)
+        .unwrap()
+        .clone(),
+      allow_missing: matches.get_flag(arg::ALLOW_MISSING),
       check: matches.get_flag(arg::CHECK),
       color: (*matches.get_one::<UseColor>(arg::COLOR).unwrap()).into(),
       command_color: matches
