@@ -1,6 +1,6 @@
 use super::*;
 
-#[derive(Default, Clone, Debug, Eq, PartialEq, Ord, PartialOrd)]
+#[derive(Clone, Debug, PartialEq, Eq, Ord, PartialOrd)]
 pub(crate) struct Namepath<'src>(Vec<Name<'src>>);
 
 impl<'src> Namepath<'src> {
@@ -14,6 +14,28 @@ impl<'src> Namepath<'src> {
       spaced: true,
     }
   }
+
+  pub(crate) fn push(&mut self, name: Name<'src>) {
+    self.0.push(name);
+  }
+
+  pub(crate) fn last(&self) -> &Name<'src> {
+    self.0.last().unwrap()
+  }
+
+  pub(crate) fn split_last(&self) -> (&Name<'src>, &[Name<'src>]) {
+    self.0.split_last().unwrap()
+  }
+
+  #[cfg(test)]
+  pub(crate) fn iter(&self) -> slice::Iter<'_, Name<'src>> {
+    self.0.iter()
+  }
+
+  #[cfg(test)]
+  pub(crate) fn len(&self) -> usize {
+    self.0.len()
+  }
 }
 
 impl Display for Namepath<'_> {
@@ -28,6 +50,12 @@ impl Display for Namepath<'_> {
   }
 }
 
+impl<'src> From<Name<'src>> for Namepath<'src> {
+  fn from(name: Name<'src>) -> Self {
+    Self(vec![name])
+  }
+}
+
 impl Serialize for Namepath<'_> {
   fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
   where
