@@ -181,7 +181,7 @@ impl Subcommand {
   }
 
   fn changelog() {
-    print!("{}", include_str!("../CHANGELOG.md"));
+    write!(io::stdout(), "{}", include_str!("../CHANGELOG.md")).ok();
   }
 
   fn choose<'src>(
@@ -239,16 +239,13 @@ impl Subcommand {
       }
     };
 
+    let stdin = child.stdin.as_mut().unwrap();
     for recipe in recipes {
-      writeln!(
-        child.stdin.as_mut().unwrap(),
-        "{}",
-        recipe.namepath.spaced()
-      )
-      .map_err(|io_error| Error::ChooserWrite {
-        io_error,
-        chooser: chooser.clone(),
-      })?;
+      if let Err(io_error) = writeln!(stdin, "{}", recipe.namepath.spaced()) {
+        if io_error.kind() != std::io::ErrorKind::BrokenPipe {
+          return Err(Error::ChooserWrite { io_error, chooser });
+        }
+      }
     }
 
     let output = match child.wait_with_output() {
@@ -432,38 +429,62 @@ impl Subcommand {
   }
 
   fn list_module(config: &Config, module: &Justfile, depth: usize) {
-    fn format_doc(
+    fn print_doc_and_aliases(
       config: &Config,
       name: &str,
       doc: Option<&str>,
+      aliases: &[&str],
       max_signature_width: usize,
       signature_widths: &BTreeMap<&str, usize>,
     ) {
+      let color = config.color.stdout();
+
+      let inline_aliases = config.alias_style != AliasStyle::Separate && !aliases.is_empty();
+
+      if inline_aliases || doc.is_some() {
+        print!(
+          "{:padding$}{}",
+          "",
+          color.doc().paint("#"),
+          padding = max_signature_width.saturating_sub(signature_widths[name]) + 1,
+        );
+      }
+
+      let print_aliases = || {
+        print!(
+          " {}",
+          color.alias().paint(&format!(
+            "[alias{}: {}]",
+            if aliases.len() == 1 { "" } else { "es" },
+            aliases.join(", ")
+          ))
+        );
+      };
+
+      if inline_aliases && config.alias_style == AliasStyle::Left {
+        print_aliases();
+      }
+
       if let Some(doc) = doc {
-        if !doc.is_empty() && doc.lines().count() <= 1 {
-          let color = config.color.stdout();
-          print!(
-            "{:padding$}{} ",
-            "",
-            color.doc().paint("#"),
-            padding = max_signature_width.saturating_sub(signature_widths[name]) + 1,
-          );
-
-          let mut end = 0;
-          for backtick in backtick_re().find_iter(doc) {
-            let prefix = &doc[end..backtick.start()];
-            if !prefix.is_empty() {
-              print!("{}", color.doc().paint(prefix));
-            }
-            print!("{}", color.doc_backtick().paint(backtick.as_str()));
-            end = backtick.end();
-          }
-
-          let suffix = &doc[end..];
-          if !suffix.is_empty() {
-            print!("{}", color.doc().paint(suffix));
+        print!(" ");
+        let mut end = 0;
+        for backtick in backtick_re().find_iter(doc) {
+          let prefix = &doc[end..backtick.start()];
+          if !prefix.is_empty() {
+            print!("{}", color.doc().paint(prefix));
           }
+          print!("{}", color.doc_backtick().paint(backtick.as_str()));
+          end = backtick.end();
         }
+
+        let suffix = &doc[end..];
+        if !suffix.is_empty() {
+          print!("{}", color.doc().paint(suffix));
+        }
+      }
+
+      if inline_aliases && config.alias_style == AliasStyle::Right {
+        print_aliases();
       }
 
       println!();
@@ -589,8 +610,14 @@ impl Subcommand {
 
       if let Some(recipes) = recipe_groups.get(&group) {
         for recipe in recipes {
+          let recipe_alias_entries = if config.alias_style == AliasStyle::Separate {
+            aliases.get(recipe.name())
+          } else {
+            None
+          };
+
           for (i, name) in iter::once(&recipe.name())
-            .chain(aliases.get(recipe.name()).unwrap_or(&Vec::new()))
+            .chain(recipe_alias_entries.unwrap_or(&Vec::new()))
             .enumerate()
           {
             let doc = if i == 0 {
@@ -616,10 +643,14 @@ impl Subcommand {
               RecipeSignature { name, recipe }.color_display(config.color.stdout())
             );
 
-            format_doc(
+            print_doc_and_aliases(
               config,
               name,
-              doc.as_deref(),
+              doc.filter(|doc| doc.lines().count() <= 1).as_deref(),
+              aliases
+                .get(recipe.name())
+                .map(Vec::as_slice)
+                .unwrap_or_default(),
               max_signature_width,
               &signature_widths,
             );
@@ -638,10 +669,11 @@ impl Subcommand {
             Self::list_module(config, submodule, depth + 1);
           } else {
             print!("{list_prefix}{} ...", submodule.name());
-            format_doc(
+            print_doc_and_aliases(
               config,
               submodule.name(),
               submodule.doc.as_deref(),
+              &[],
               max_signature_width,
               &signature_widths,
             );
