@@ -2,11 +2,11 @@ use super::*;
 
 #[derive(PartialEq, Debug, Clone)]
 pub(crate) struct UnresolvedDependency<'src> {
-  pub(crate) recipe: Name<'src>,
   pub(crate) arguments: Vec<Expression<'src>>,
+  pub(crate) recipe: Name<'src>,
 }
 
-impl<'src> Display for UnresolvedDependency<'src> {
+impl Display for UnresolvedDependency<'_> {
   fn fmt(&self, f: &mut Formatter) -> fmt::Result {
     if self.arguments.is_empty() {
       write!(f, "{}", self.recipe)
