@@ -6,9 +6,10 @@ fn all() {
     .justfile(
       "
       [macos]
-      [windows]
       [linux]
+      [openbsd]
       [unix]
+      [windows]
       [no-exit-message]
       foo:
         exit 1
@@ -48,7 +49,7 @@ fn multiple_attributes_one_line() {
   Test::new()
     .justfile(
       "
-      [macos, windows,linux]
+      [macos,windows,linux,openbsd]
       [no-exit-message]
       foo:
         exit 1
@@ -64,7 +65,7 @@ fn multiple_attributes_one_line_error_message() {
   Test::new()
     .justfile(
       "
-      [macos, windows linux]
+      [macos,windows linux,openbsd]
       [no-exit-message]
       foo:
         exit 1
@@ -73,10 +74,10 @@ fn multiple_attributes_one_line_error_message() {
     .stderr(
       "
         error: Expected ']', ':', ',', or '(', but found identifier
-         ——▶ justfile:1:17
+         ——▶ justfile:1:16
           │
-        1 │ [macos, windows linux]
-          │                 ^^^^^
+        1 │ [macos,windows linux,openbsd]
+          │                ^^^^^
           ",
     )
     .status(1)
@@ -88,7 +89,7 @@ fn multiple_attributes_one_line_duplicate_check() {
   Test::new()
     .justfile(
       "
-      [macos, windows, linux]
+      [macos, windows, linux, openbsd]
       [linux]
       foo:
         exit 1
@@ -230,3 +231,26 @@ fn extension_on_linewise_error() {
     .status(EXIT_FAILURE)
     .run();
 }
+
+#[test]
+fn duplicate_non_repeatable_attributes_are_forbidden() {
+  Test::new()
+    .justfile(
+      "
+        [confirm: 'yes']
+        [confirm: 'no']
+        baz:
+      ",
+    )
+    .stderr(
+      "
+  error: Recipe attribute `confirm` first used on line 1 is duplicated on line 2
+   ——▶ justfile:2:2
+    │
+  2 │ [confirm: 'no']
+    │  ^^^^^^^
+",
+    )
+    .status(EXIT_FAILURE)
+    .run();
+}
