@@ -31,7 +31,7 @@ struct Interpreter<'a> {
   command: &'a str,
 }
 
-#[derive(Debug, Default, PartialEq, Serialize)]
+#[derive(Debug, Default, PartialEq, Serialize, Deserialize)]
 #[serde(deny_unknown_fields)]
 struct Module<'a> {
   aliases: BTreeMap<&'a str, Alias<'a>>,
@@ -42,6 +42,7 @@ struct Module<'a> {
   modules: BTreeMap<&'a str, Module<'a>>,
   recipes: BTreeMap<&'a str, Recipe<'a>>,
   settings: Settings<'a>,
+  source: PathBuf,
   unexports: Vec<&'a str>,
   warnings: Vec<&'a str>,
 }
@@ -83,6 +84,7 @@ struct Settings<'a> {
   export: bool,
   fallback: bool,
   ignore_comments: bool,
+  no_exit_message: bool,
   positional_arguments: bool,
   quiet: bool,
   shell: Option<Interpreter<'a>>,
@@ -98,8 +100,26 @@ fn case(justfile: &str, expected: Module) {
   case_with_submodule(justfile, None, expected);
 }
 
+fn fix_source(dir: &Path, module: &mut Module) {
+  let filename = if module.source.as_os_str().is_empty() {
+    Path::new("justfile")
+  } else {
+    &module.source
+  };
+
+  module.source = if cfg!(target_os = "macos") {
+    dir.canonicalize().unwrap().join(filename)
+  } else {
+    dir.join(filename)
+  };
+
+  for module in module.modules.values_mut() {
+    fix_source(dir, module);
+  }
+}
+
 #[track_caller]
-fn case_with_submodule(justfile: &str, submodule: Option<(&str, &str)>, expected: Module) {
+fn case_with_submodule(justfile: &str, submodule: Option<(&str, &str)>, mut expected: Module) {
   let mut test = Test::new()
     .justfile(justfile)
     .args(["--dump", "--dump-format", "json"])
@@ -109,11 +129,11 @@ fn case_with_submodule(justfile: &str, submodule: Option<(&str, &str)>, expected
     test = test.write(path, source);
   }
 
+  fix_source(test.tempdir.path(), &mut expected);
+
   let actual = test.run().stdout;
 
-  let mut expected = serde_json::to_string(&expected).unwrap();
-  expected.push('\n');
-
+  let actual: Module = serde_json::from_str(actual.as_str()).unwrap();
   pretty_assertions::assert_eq!(actual, expected);
 }
 
@@ -776,6 +796,7 @@ fn module() {
         Module {
           doc: Some("hello"),
           first: Some("bar"),
+          source: "foo.just".into(),
           recipes: [(
             "bar",
             Recipe {
@@ -808,6 +829,7 @@ fn module_group() {
         Module {
           first: Some("bar"),
           groups: ["alpha"].into(),
+          source: "foo.just".into(),
           recipes: [(
             "bar",
             Recipe {
