@@ -6,10 +6,11 @@ pub(crate) use {
     test::{assert_eval_eq, Output, Test},
   },
   executable_path::executable_path,
-  just::unindent,
+  just::{unindent, Response},
   libc::{EXIT_FAILURE, EXIT_SUCCESS},
   pretty_assertions::Comparison,
   regex::Regex,
+  serde::{Deserialize, Serialize},
   serde_json::{json, Value},
   std::{
     collections::BTreeMap,
@@ -28,14 +29,22 @@ pub(crate) use {
   which::which,
 };
 
+fn default<T: Default>() -> T {
+  Default::default()
+}
+
 #[macro_use]
 mod test;
 
+mod alias;
+mod alias_style;
 mod allow_duplicate_recipes;
 mod allow_duplicate_variables;
+mod allow_missing;
 mod assert_stdout;
 mod assert_success;
 mod assertions;
+mod assignment;
 mod attributes;
 mod backticks;
 mod byte_order_mark;
@@ -58,7 +67,7 @@ mod examples;
 mod explain;
 mod export;
 mod fallback;
-mod fmt;
+mod format;
 mod functions;
 #[cfg(unix)]
 mod global;
@@ -72,6 +81,7 @@ mod invocation_directory;
 mod json;
 mod line_prefixes;
 mod list;
+mod logical_operators;
 mod man;
 mod misc;
 mod modules;
@@ -91,6 +101,7 @@ mod quote;
 mod readme;
 mod recursion_limit;
 mod regexes;
+mod request;
 mod run;
 mod script;
 mod search;
@@ -109,6 +120,7 @@ mod timestamps;
 mod undefined_variables;
 mod unexport;
 mod unstable;
+mod which_function;
 #[cfg(windows)]
 mod windows;
 #[cfg(target_family = "windows")]
