@@ -1,133 +1,177 @@
 use super::*;
 
-test! {
-  name:     no_stdout,
-  justfile: r#"
+#[test]
+fn no_stdout() {
+  Test::new()
+    .arg("--quiet")
+    .justfile(
+      r"
 default:
   @echo hello
-"#,
-  args:     ("--quiet"),
-  stdout:   "",
+",
+    )
+    .run();
 }
 
-test! {
-  name:     stderr,
-  justfile: r#"
+#[test]
+fn stderr() {
+  Test::new()
+    .arg("--quiet")
+    .justfile(
+      r"
 default:
   @echo hello 1>&2
-"#,
-  args:     ("--quiet"),
-  stdout:   "",
+",
+    )
+    .run();
 }
 
-test! {
-  name:     command_echoing,
-  justfile: r#"
+#[test]
+fn command_echoing() {
+  Test::new()
+    .arg("--quiet")
+    .justfile(
+      r"
 default:
   exit
-"#,
-  args:     ("--quiet"),
-  stdout:   "",
+",
+    )
+    .run();
 }
 
-test! {
-  name:     error_messages,
-  justfile: r#"
+#[test]
+fn error_messages() {
+  Test::new()
+    .arg("--quiet")
+    .justfile(
+      r"
 default:
   exit 100
-"#,
-  args:     ("--quiet"),
-  stdout:   "",
-  status:   100,
+",
+    )
+    .status(100)
+    .run();
 }
 
-test! {
-  name:     assignment_backtick_stderr,
-  justfile: r#"
+#[test]
+fn assignment_backtick_stderr() {
+  Test::new()
+    .arg("--quiet")
+    .justfile(
+      r"
 a := `echo hello 1>&2`
 default:
   exit 100
-"#,
-  args:     ("--quiet"),
-  stdout:   "",
-  status:   100,
+",
+    )
+    .status(100)
+    .run();
 }
 
-test! {
-  name:     interpolation_backtick_stderr,
-  justfile: r#"
+#[test]
+fn interpolation_backtick_stderr() {
+  Test::new()
+    .arg("--quiet")
+    .justfile(
+      r"
 default:
   echo `echo hello 1>&2`
   exit 100
-"#,
-  args:     ("--quiet"),
-  stdout:   "",
-  status:   100,
+",
+    )
+    .status(100)
+    .run();
 }
 
-test! {
-  name: choose_none,
-  justfile: "",
-  args: ("--choose", "--quiet"),
-  status: EXIT_FAILURE,
+#[test]
+fn choose_none() {
+  Test::new()
+    .arg("--choose")
+    .arg("--quiet")
+    .justfile("")
+    .status(EXIT_FAILURE)
+    .run();
 }
 
-test! {
-  name: choose_invocation,
-  justfile: "foo:",
-  args: ("--choose", "--quiet", "--shell", "asdfasdfasfdasdfasdfadsf"),
-  status: EXIT_FAILURE,
-  shell: false,
+#[test]
+fn choose_invocation() {
+  Test::new()
+    .arg("--choose")
+    .arg("--quiet")
+    .arg("--shell")
+    .arg("asdfasdfasfdasdfasdfadsf")
+    .justfile("foo:")
+    .shell(false)
+    .status(EXIT_FAILURE)
+    .run();
 }
 
-test! {
-  name: choose_status,
-  justfile: "foo:",
-  args: ("--choose", "--quiet", "--chooser", "/usr/bin/env false"),
-  status: EXIT_FAILURE,
+#[test]
+fn choose_status() {
+  Test::new()
+    .arg("--choose")
+    .arg("--quiet")
+    .arg("--chooser")
+    .arg("/usr/bin/env false")
+    .justfile("foo:")
+    .status(EXIT_FAILURE)
+    .run();
 }
 
-test! {
-  name: edit_invocation,
-  justfile: "foo:",
-  args: ("--edit", "--quiet"),
-  env: {
-    "VISUAL": "adsfasdfasdfadsfadfsaf",
-  },
-  status: EXIT_FAILURE,
+#[test]
+fn edit_invocation() {
+  Test::new()
+    .arg("--edit")
+    .arg("--quiet")
+    .env("VISUAL", "adsfasdfasdfadsfadfsaf")
+    .justfile("foo:")
+    .status(EXIT_FAILURE)
+    .run();
 }
 
-test! {
-  name: edit_status,
-  justfile: "foo:",
-  args: ("--edit", "--quiet"),
-  env: {
-    "VISUAL": "false",
-  },
-  status: EXIT_FAILURE,
+#[test]
+fn edit_status() {
+  Test::new()
+    .arg("--edit")
+    .arg("--quiet")
+    .env("VISUAL", "false")
+    .justfile("foo:")
+    .status(EXIT_FAILURE)
+    .run();
 }
 
-test! {
-  name: init_exists,
-  justfile: "foo:",
-  args: ("--init", "--quiet"),
-  status: EXIT_FAILURE,
+#[test]
+fn init_exists() {
+  Test::new()
+    .arg("--init")
+    .arg("--quiet")
+    .justfile("foo:")
+    .status(EXIT_FAILURE)
+    .run();
 }
 
-test! {
-  name: show_missing,
-  justfile: "foo:",
-  args: ("--show", "bar", "--quiet"),
-  status: EXIT_FAILURE,
+#[test]
+fn show_missing() {
+  Test::new()
+    .arg("--show")
+    .arg("bar")
+    .arg("--quiet")
+    .justfile("foo:")
+    .status(EXIT_FAILURE)
+    .run();
 }
 
-test! {
-  name: quiet_shebang,
-  justfile: "
+#[test]
+fn quiet_shebang() {
+  Test::new()
+    .arg("--quiet")
+    .justfile(
+      "
     @foo:
       #!/bin/sh
   ",
-  args: ("--quiet"),
+    )
+    .run();
 }
 
 #[test]
