@@ -3,40 +3,6 @@ use {
   pretty_assertions::{assert_eq, StrComparison},
 };
 
-macro_rules! test {
-  {
-    name: $name:ident,
-    $(justfile: $justfile:expr,)?
-    $(args: ($($arg:tt),*),)?
-    $(env: { $($env_key:literal : $env_value:literal,)* },)?
-    $(stdin: $stdin:expr,)?
-    $(stdout: $stdout:expr,)?
-    $(stdout_regex: $stdout_regex:expr,)?
-    $(stderr: $stderr:expr,)?
-    $(stderr_regex: $stderr_regex:expr,)?
-    $(status: $status:expr,)?
-    $(shell: $shell:expr,)?
-  } => {
-    #[test]
-    fn $name() {
-      let test = crate::test::Test::new();
-
-      $($(let test = test.arg($arg);)*)?
-      $($(let test = test.env($env_key, $env_value);)*)?
-      $(let test = test.justfile($justfile);)?
-      $(let test = test.shell($shell);)?
-      $(let test = test.status($status);)?
-      $(let test = test.stderr($stderr);)?
-      $(let test = test.stderr_regex($stderr_regex);)?
-      $(let test = test.stdin($stdin);)?
-      $(let test = test.stdout($stdout);)?
-      $(let test = test.stdout_regex($stdout_regex);)?
-
-      test.run();
-    }
-  }
-}
-
 pub(crate) struct Output {
   pub(crate) pid: u32,
   pub(crate) stdout: String,
@@ -205,6 +171,30 @@ impl Test {
     self
   }
 
+  pub(crate) fn make_executable(self, path: impl AsRef<Path>) -> Self {
+    let file = self.tempdir.path().join(path);
+
+    // Make sure it exists first, as a sanity check.
+    assert!(file.exists(), "file does not exist: {}", file.display());
+
+    // Windows uses file extensions to determine whether a file is executable.
+    // Other systems don't care. To keep these tests cross-platform, just make
+    // sure all executables end with ".exe" suffix.
+    assert!(
+      file.extension() == Some("exe".as_ref()),
+      "executable file does not end with .exe: {}",
+      file.display()
+    );
+
+    #[cfg(unix)]
+    {
+      let perms = std::os::unix::fs::PermissionsExt::from_mode(0o755);
+      fs::set_permissions(file, perms).unwrap();
+    }
+
+    self
+  }
+
   pub(crate) fn expect_file(mut self, path: impl AsRef<Path>, content: impl AsRef<[u8]>) -> Self {
     let path = path.as_ref();
     self
